#
# spec file for package gyp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nurenberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gyp
Version:        0+git.20171012
Release:        bp153.1.13
Summary:        Generate Your Projects
License:        BSD-3-Clause
Group:          Development/Tools/Building
Url:            https://gyp.gsrc.io
Source:         %{name}-%{version}.tar.xz
Patch0:         gyp-rpmoptflags.patch
BuildRequires:  fdupes
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
Requires:       python2-setuptools
BuildArch:      noarch

%description
GYP is a tool to generates native Visual Studio, Xcode and SCons and/or make
build files from a platform-independent input format. Its syntax is a universal
cross-platform build representation that still allows sufficient per-platform
flexibility to accommodate irreconcilable differences

%prep
%setup -q
%patch0
for i in $(find pylib -name '*.py'); do
	sed -e '\,#![ \t]*/.*python,{d}' $i > $i.new && touch -r $i $i.new && mv $i.new $i
done
sed -i '/^#!/d' ./pylib/%{name}/*.py
sed -i '/^#!/d' ./pylib/%{name}/generator/*.py

%build
python2 setup.py build

%install
python2 setup.py install --root %{buildroot} --prefix=%{_prefix}
%fdupes -s %{buildroot}%{python_sitelib}

%files
%doc AUTHORS LICENSE
%{_bindir}/%{name}
%{python_sitelib}/*

%changelog
* Thu Nov  2 2017 mpluskal@suse.com
- Update to version 0+git.20171012:
  * Remove Rietveld CQ config.
  * Flip to LUCI for tryjobs.
  * Provide backward compatibility for python 2.7.6 on z/OS
  * Add LIBS to the link command on z/OS
  * Change z/OS platform flavor name based on python 2.7.13
* Mon Sep  4 2017 mpluskal@suse.com
- Update to version 0+git.20170904:
  * [win-test] loosen win-driver-target-type test
  * [win] Add support for MS VS2017 (via Registry)
  * Update test/no-cpp/gyptest-no-cpp.
  * Disable a bunch of tests on Mac.
  * Clean up gyptest.py.
  * win,ninja: ninja generator better on windows
  * Disable flaky test/copies/gyptest-all under msvs.
  * Fix MSVC++ 32-on-32 builds after b62d04ff85e6
  * win ninja/make: Always use a native compiler executable with MSVS 2017
  * win: mkdir even when copying directory
  * mac_tool.py: Handle non-zero ibtool return code.
  * gyp: update xml string encoding conversion
  * gyp: show descriptive Windows SDK detection error
  * Support z/OS platform
  * make,ninja: Add support for an LDFLAGS_host environment variable.
* Wed Apr  5 2017 mpluskal@suse.com
- Update to version 0+git.20170303:
  * Set up a CQ for gyp
  * Make Gerrit the default code review system for gyp
  * CQ config: add gerrit CQAbility verifier.
* Fri Jan 13 2017 mpluskal@suse.com
- Update to version 0+git.20161117:
  * fix common "NameError"s
  * Hash intermediate file name to avoid ENAMETOOLONG
  * msvs: Allow target platform version without WinRT
  * Update shared library extension on AIX to .a.
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 0+git.20160810:
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
  * Enabling /ZW (CompileAsWinRT) option for msvs
  * ninja/mac: Add horrible workaround for horrible Xcode 7.3 ld bug.
  * [gyp-ninja] Set simulator and device SDKROOT for iOS.
  * Ignore more Xcode stderr logging information.
  * Only call CopyStringsFile if convert_to_binary is False.
  * Fix :rfc1034identifier when the value contains underscore.
  * Complete PBXCopyFilesBuildPhase TODO in xcodeproj_file.py.
  * Make the ninja backend transitively check for C++ sources to use the C++ compiler for linking
  * Add new target type called windows_driver. * Modify GYP to set the PlatformToolset, the DriverType and the TargetVersion * Add msvs_target_version configuration
* Wed Jul  6 2016 mpluskal@suse.com
- Update to version 0+git.20160620:
  * [gyp-ninja] Set simulator and device SDKROOT for iOS.
  * Ignore more Xcode stderr logging information.
* Tue Jun 14 2016 mpluskal@suse.com
- Update to version 0+git.20160513:
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
  * Fix header map nextPowerOf2 method.
  * [ios-ninja] Support xctests in devices in release.
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
  * Enabling /ZW (CompileAsWinRT) option for msvs
  * ninja/mac: Add horrible workaround for horrible Xcode 7.3 ld bug.
* Thu May  5 2016 mpluskal@suse.com
- Update to version 0+git.20160504:
  * [GN] Use hard-link if possible when copying to bundle.
* Tue May  3 2016 mpluskal@suse.com
- Update to version 0+git.20160426:
  * Support DEVELOPER_DIR in gyp-ninja for mac.
  * [GN] Use hard-link if possible when copying to bundle.
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
  * Fix header map nextPowerOf2 method.
  * [ios-ninja] Support xctests in devices in release.
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
* Fri Apr 15 2016 mpluskal@suse.com
- Update to version 0+git.20160413:
  * ninja: Add target_rpath generator flag
  * Add support for iOS Frameworks with header maps.
  * Detect and warn on missing vcvarsall.bat
  * Support DEVELOPER_DIR in gyp-ninja for mac.
  * [GN] Use hard-link if possible when copying to bundle.
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
* Sun Mar 20 2016 mpluskal@suse.com
- Update to version 0~git.20160318:
  + Revert "Update Xcode emulation extra plist items."
  + Re-land update Xcode emulation extra plist items for Xcode 7.2
  + Support sdk_version of None.
  + Don't recompute environment for mac bundles unnecessarily.
  + Make login.keychain and 'Provisioning Profiles' symlinks.
  + Fix tests with Xcode 7.
  + Xcode-ninja: Add excluded files to the project sources_for_indexing.xcodeproj
  + ninja/win: Use qualified paths for precompiled headers.
  + Adjust pretty_gyp to align comments with the appropriate braces.
  + ninja: Add target_rpath generator flag
- Small spec file cleanup
* Wed Mar  9 2016 mpluskal@suse.com
- Update to version 0~git.20160304:
  + [Mac/iOS] Add custom fonts, target device and minimum
    ployment target to _CopyXIBFile
  + Update Xcode emulation extra plist items.
  + Revert "Update Xcode emulation extra plist items."
  + Re-land update Xcode emulation extra plist items for Xcode 7.2
  + Support sdk_version of None.
  + Don't recompute environment for mac bundles unnecessarily.
  + Make login.keychain and 'Provisioning Profiles' symlinks.
  + Fix tests with Xcode 7.
  + Xcode-ninja: Add excluded files to the project
    urces_for_indexing.xcodeproj
  + ninja/win: Use qualified paths for precompiled headers.
- Add _service
- Cleanup spec file with spec-cleaner
* Sat Aug  8 2015 p.drouand@gmail.com
- Update to master latest revision
- Add python-setuptools dependency
- Add gyp-rpmoptflags.patch
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to latest svn revision
* Wed Sep  5 2012 p.drouand@gmail.com
- Initial release
